package com.ghy.order.service;
import java.util.List;
import com.ghy.order.domain.OrderDetailInsuranceUser;

/**
 * 订单保险人员Service接口
 *
 * @author clunt
 * @date 2024-10-21
 */
public interface IOrderDetailInsuranceUserService
{
    /**
     * 查询订单保险人员
     *
     * @param id 订单保险人员主键
     * @return 订单保险人员
     */
    public OrderDetailInsuranceUser selectOrderDetailInsuranceUserById(Long id);

    /**
     * 查询订单保险人员列表
     *
     * @param orderDetailInsuranceUser 订单保险人员
     * @return 订单保险人员集合
     */
    public List<OrderDetailInsuranceUser> selectOrderDetailInsuranceUserList(OrderDetailInsuranceUser orderDetailInsuranceUser);

    /**
     * 新增订单保险人员
     *
     * @param orderDetailInsuranceUser 订单保险人员
     * @return 结果
     */
    public int insertOrderDetailInsuranceUser(OrderDetailInsuranceUser orderDetailInsuranceUser);

    /**
     * 修改订单保险人员
     *
     * @param orderDetailInsuranceUser 订单保险人员
     * @return 结果
     */
    public int updateOrderDetailInsuranceUser(OrderDetailInsuranceUser orderDetailInsuranceUser);

    /**
     * 批量删除订单保险人员
     *
     * @param ids 需要删除的订单保险人员主键集合
     * @return 结果
     */
    public int deleteOrderDetailInsuranceUserByIds(String ids);

    /**
     * 删除订单保险人员信息
     *
     * @param id 订单保险人员主键
     * @return 结果
     */
    public int deleteOrderDetailInsuranceUserById(Long id);
}
